.. -*- coding: utf-8 -*-

*********
Tutorials
*********

Here are a few tutorials with different difficulty levels.

Beginners will want to start with the blog building tutorial giving a short introduction to the basic concepts.
Then the photo gallery construction tutorial highlights
more advanced concepts such as unit tests, security settings and migration scripts.

The other tutorials cover specific topics you can learn about when you understand the basics.

.. toctree::
    :maxdepth: 1

    base/index
    advanced/index
    dataimport/index
    museum/index
